summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--win/tclWinInit.c11
1 files changed, 9 insertions, 2 deletions
diff --git a/win/tclWinInit.c b/win/tclWinInit.c
index 2a02872..27b86d5 100644
--- a/win/tclWinInit.c
+++ b/win/tclWinInit.c
@@ -7,7 +7,7 @@
* Copyright (c) 1998-1999 by Scriptics Corporation.
* All rights reserved.
*
- * RCS: @(#) $Id: tclWinInit.c,v 1.18 1999/07/21 02:01:37 hershey Exp $
+ * RCS: @(#) $Id: tclWinInit.c,v 1.19 1999/07/21 23:28:05 hershey Exp $
*/
#include "tclWinInt.h"
@@ -532,7 +532,8 @@ TclpSetInitialEncodings()
* None.
*
* Side effects:
* Sets "tcl_platform" and "env(HOME)" Tcl variables.
*
*----------------------------------------------------------------------
*/
@@ -563,6 +564,12 @@ TclpSetVariables(interp)
}
/*
+ * Initialize the tclDefaultLibrary variable from the registry.
+ */
+
+ Tcl_SetVar(interp, "tclDefaultLibrary", "", TCL_GLOBAL_ONLY);
+
+ /*
* Define the tcl_platform array.
*/
@@ -532,7 +532,8 @@ TclpSetInitialEncodings()
*
* Side effects:
- * Sets "tcl_platform" and "env(HOME)" Tcl variables.
+ * Sets "tclDefaultLibrary", "tcl_platform", and "env(HOME)" Tcl
+ * variables.
*
*----------------------------------------------------------------------